# DeMeXpy - Python
Python implementation of the Decentralized Message Exchange protocol. Send and recieve python objects on different devices even if they are not connected to the same network. Uses `ntfy.sh` for communication (any host can be used; even self-hosted ones). Supports function calling on the reciever's end. All communication is fully encrypted end-to-end.

## Installation
```bash
pip install demexpy
```

## Usage
See [docs](docs/index.md).
